==> simple-react-form-2.1.0.tgz: package/lib/WithValue/index.test.js <==
'use strict';

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _class, _temp;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _testUtils = require('react-dom/test-utils');

var _testUtils2 = _interopRequireDefault(_testUtils);

var _Form = require('../Form');

var _Form2 = _interopRequireDefault(_Form);

var _Field = require('../Field');

var _Field2 = _interopRequireDefault(_Field);

var _index = require('./index');

var _index2 = _interopRequireDefault(_index);

require('../setupTest');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _Object = require('../Object');

var _Object2 = _interopRequireDefault(_Object);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var DummyInput = (_temp = _class = function (_React$Component) {
  (0, _inherits3.default)(DummyInput, _React$Component);

  function DummyInput() {
    (0, _classCallCheck3.default)(this, DummyInput);
    return (0, _possibleConstructorReturn3.default)(this, (DummyInput.__proto__ || Object.getPrototypeOf(DummyInput)).apply(this, arguments));
  }

  (0, _createClass3.default)(DummyInput, [{
    key: 'render',
    value: function render() {
      var _this2 = this;

      return _react2.default.createElement('input', {
        value: this.props.value || '',
        onChange: function onChange(event) {
          _this2.props.onChange(event.target.value);
        }
      });
    }
  }]);
  return DummyInput;
}(_react2.default.Component), _class.propTypes = {
  value: _propTypes2.default.string,
  onChange: _propTypes2.default.func
}, _temp);


it('should pass the value of the form', function () {
  var tree = _testUtils2.default.renderIntoDocument(_react2.default.createElement(
    _Form2.default,
    { state: { name: 'Nicolás' } },
    _react2.default.createElement(
      _index2.default,
      null,
      function (value) {
        return _react2.default.createElement(
          'div',
          null,
          _react2.default.createElement(
            'div',
            { className: 'theValue' },
            value.name
          ),
          _react2.default.createElement(_Field2.default, { fieldName: 'name', type: DummyInput })
        );
      }
    )
  ));

  var content = _testUtils2.default.findRenderedDOMComponentWithClass(tree, 'theValue');
  expect(content.innerHTML).toBe('Nicolás');
});

it('should pass the value of the form on sub object data', function () {
  var doc = { person: { name: 'Nicolás' } };
  var tree = _testUtils2.default.renderIntoDocument(_react2.default.createElement(
    _Form2.default,
    { state: doc },
    _react2.default.createElement(
      _Field2.default,
      { fieldName: 'person', type: _Object2.default },
      _react2.default.createElement(
        _index2.default,
        null,
        function (person) {
          return _react2.default.createElement(
            'div',
            null,
            _react2.default.createElement(
              'div',
              { className: 'theValue' },
              person.name
            ),
            _react2.default.createElement(_Field2.default, { fieldName: 'name', type: DummyInput })
          );
        }
      )
    )
  ));

  var content = _testUtils2.default.findRenderedDOMComponentWithClass(tree, 'theValue');
  expect(content.innerHTML).toBe('Nicolás');
});

==> simple-react-form-2.5.0.tgz: package/lib/WithValue/index.test.js <==
'use strict';

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _testUtils = require('react-dom/test-utils');

var _testUtils2 = _interopRequireDefault(_testUtils);

var _Form = require('../Form');

var _Form2 = _interopRequireDefault(_Form);

var _Field = require('../Field');

var _Field2 = _interopRequireDefault(_Field);

var _index = require('./index');

var _index2 = _interopRequireDefault(_index);

require('../setupTest');

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _Object = require('../Object');

var _Object2 = _interopRequireDefault(_Object);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var DummyInput = function (_React$Component) {
  (0, _inherits3.default)(DummyInput, _React$Component);

  function DummyInput() {
    (0, _classCallCheck3.default)(this, DummyInput);
    return (0, _possibleConstructorReturn3.default)(this, (DummyInput.__proto__ || Object.getPrototypeOf(DummyInput)).apply(this, arguments));
  }

  (0, _createClass3.default)(DummyInput, [{
    key: 'render',
    value: function render() {
      var _this2 = this;

      return _react2.default.createElement('input', {
        value: this.props.value || '',
        onChange: function onChange(event) {
          _this2.props.onChange(event.target.value);
        }
      });
    }
  }]);
  return DummyInput;
}(_react2.default.Component);

DummyInput.propTypes = {
  value: _propTypes2.default.string,
  onChange: _propTypes2.default.func
};


it('should pass the value of the form', function () {
  var tree = _testUtils2.default.renderIntoDocument(_react2.default.createElement(
    _Form2.default,
    { state: { name: 'Nicolás' } },
    _react2.default.createElement(
      _index2.default,
      null,
      function (value) {
        return _react2.default.createElement(
          'div',
          null,
          _react2.default.createElement(
            'div',
            { className: 'theValue' },
            value.name
          ),
          _react2.default.createElement(_Field2.default, { fieldName: 'name', type: DummyInput })
        );
      }
    )
  ));

  var content = _testUtils2.default.findRenderedDOMComponentWithClass(tree, 'theValue');
  expect(content.innerHTML).toBe('Nicolás');
});

it('should pass the value of the form on sub object data', function () {
  var doc = { person: { name: 'Nicolás' } };
  var tree = _testUtils2.default.renderIntoDocument(_react2.default.createElement(
    _Form2.default,
    { state: doc },
    _react2.default.createElement(
      _Field2.default,
      { fieldName: 'person', type: _Object2.default },
      _react2.default.createElement(
        _index2.default,
        null,
        function (person) {
          return _react2.default.createElement(
            'div',
            null,
            _react2.default.createElement(
              'div',
              { className: 'theValue' },
              person.name
            ),
            _react2.default.createElement(_Field2.default, { fieldName: 'name', type: DummyInput })
          );
        }
      )
    )
  ));

  var content = _testUtils2.default.findRenderedDOMComponentWithClass(tree, 'theValue');
  expect(content.innerHTML).toBe('Nicolás');
});
